# -*- coding: utf8 -*-
from django.urls import reverse
from django.http import Http404
from django.shortcuts import render, redirect
from django.contrib import messages

from club.models import Inutilisateur
from portailuser.models import PortailUser
from portailuser.app_logger import AppLogger
from gestion.clubs.views import nom_uid
from ldap_inp import LdapGroupe
from lib.access_auth import permission_needed


_logger = AppLogger("gestion_groupes")


@permission_needed("gerer_groupes")
def liste(request):
    groupes = sorted(
        LdapGroupe.objects.filter(cn__matching="*-" + request.ecole.ident),
        key=lambda g: g.displayName.lower(),
    )

    return render(request, "gestion/groupes/liste.html", locals())


@permission_needed("gerer_groupes")
def gestion(request, groupe_id, uid=None):
    try:
        groupe = LdapGroupe.objects.get(cn=f"{groupe_id}-{request.ecole.ident}")
    except LdapGroupe.DoesNotExist:
        raise Http404

    # ajout d'un membre au groupe
    if uid:
        if uid not in groupe.memberUid:
            groupe.memberUid.append(uid)
            groupe.save()
            _logger.log(request.user, f"A ajouté {nom_uid(uid)} ({uid}) au groupe {groupe_id}")
            messages.success(request, f"{nom_uid(uid)} a été ajouté au groupe.")
            return redirect(reverse("gestion:groupes:gestion", args=[groupe_id]) + "#ajoutmembre")

    # suppression d'un membre du groupe
    if request.method == "POST":
        liste = request.POST.getlist("membre")
        membres = []

        for membre in request.POST.getlist("membre"):
            try:
                groupe.memberUid.remove(membre)
                groupe.save()
                _logger.log(
                    request.user,
                    f"A retiré {nom_uid(membre)} ({membre}) du groupe {groupe_id}",
                )
                membres.append(membre)
            except Exception:
                pass

        noms = ", ".join([nom_uid(uid_) for uid_ in liste])
        if len(membres):
            messages.success(
                request,
                "{} {} du groupe".format(noms, "a été supprimé" if len(liste) == 1 else "ont été supprimés"),
            )

            return redirect("gestion:groupes:gestion", groupe_id=groupe_id)

    membres = []

    for uid in groupe.memberUid:
        try:
            membres.append(PortailUser.objects.get_from_ldap(uid))
        except PortailUser.DoesNotExist:
            membres.append(Inutilisateur(uid))

    membres.sort(key=(lambda x: x.username))

    c = {
        "groupe": groupe.displayName,
        "ident": groupe_id,
        "membres": membres,
    }

    return render(request, "gestion/groupes/gestion.html", c)
